"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsonata = require("jsonata");
const chai_1 = require("chai");
const regexMatcher_1 = require("../lib/regexMatcher");
const webhook_receiver_1 = require("../lib/webhook-receiver");
let r;
exports.webhookStepRunners = () => [
    {
        willRun: regexMatcher_1.regexMatcher(/^the Webhook Receiver "([^"]+)" should be called$/),
        run: async ([MessageGroupId], _, runner) => r.receiveWebhookRequest(MessageGroupId, runner).then(r => r.body),
    },
    {
        willRun: regexMatcher_1.regexMatcher(/^"([^"]+)" of the webhook request body should equal "([^"]+)"$/),
        run: async ([exp, expected]) => {
            const e = jsonata(exp);
            chai_1.expect(r.latestWebhookRequest).not.to.be.an('undefined');
            const b = r.latestWebhookRequest && r.latestWebhookRequest.body;
            chai_1.expect(b).not.to.be.an('undefined');
            const result = e.evaluate(b);
            chai_1.expect(result).to.deep.equal(expected);
            return b;
        },
    },
    {
        willRun: regexMatcher_1.regexMatcher(/^the webhook request body should equal this JSON$/),
        run: async (_, step) => {
            if (!step.interpolatedArgument) {
                throw new Error('Must provide argument!');
            }
            const j = JSON.parse(step.interpolatedArgument);
            const b = r.latestWebhookRequest && r.latestWebhookRequest.body;
            chai_1.expect(b).not.to.be.an('undefined');
            chai_1.expect(b).to.deep.equal(j);
            return b;
        },
    },
    {
        willRun: regexMatcher_1.regexMatcher(/^I have a Webhook Receiver/),
        run: async (_, __, runner) => {
            r = new webhook_receiver_1.WebhookReceiver(runner.world.webhookQueue);
            await r.clearQueue();
        },
    },
];
